# Sparse Gaussian Process Variational Autoencoders

This repository contains the Python implementation of the SGP-VAE, introduced in our [paper](https://openreview.net/forum?id=czv8Ac3Kg7l).

The main components of the repository are:
* `sgpvae`: the implementation of the SGP-VAE and partial inference networks.
* `experiments`: code for running the experiments detailed in the paper.
* `data`: code for installing the datasets used in the experiments.

### Dependencies
This code is implemented in Python 3.8.

### Contact
Please do feel free to use/extend this code for your own research. Indeed, the models in `sgpvae` are implemented with versatility in mind, so should be easily applied to a wide range of datasets. If you have any questions, or would like to report any issues, please open an issue on the issues tracker or contact me at <mca39@cam.ac.uk>.
